# coding: utf-8

"""
    ****************************************************************************
    Copyright (c) 2016-present,
    Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp. All rights reserved.

    This file is part of Catapult.

    Catapult is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Catapult is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Catapult. If not, see <http://www.gnu.org/licenses/>.
    ****************************************************************************
    
    Catapult REST Endpoints
    OpenAPI Specification of catapult-rest 2.2.0  # noqa: E501
    The version of the OpenAPI document: 0.10.4
    Contact: contact@nem.foundation

    NOTE: This file is auto generated by Symbol OpenAPI Generator:
    https://github.com/nemtech/symbol-openapi-generator
    Do not edit this file manually.
"""


import pprint
import re  # noqa: F401

import six

from symbol_openapi_client.configuration import Configuration


class TransactionStatusEnum(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    SUCCESS = "Success"
    NEUTRAL = "Neutral"
    FAILURE = "Failure"
    FAILURE_CORE_PAST_DEADLINE = "Failure_Core_Past_Deadline"
    FAILURE_CORE_FUTURE_DEADLINE = "Failure_Core_Future_Deadline"
    FAILURE_CORE_INSUFFICIENT_BALANCE = "Failure_Core_Insufficient_Balance"
    FAILURE_CORE_TOO_MANY_TRANSACTIONS = "Failure_Core_Too_Many_Transactions"
    FAILURE_CORE_NEMESIS_ACCOUNT_SIGNED_AFTER_NEMESIS_BLOCK = "Failure_Core_Nemesis_Account_Signed_After_Nemesis_Block"
    FAILURE_CORE_WRONG_NETWORK = "Failure_Core_Wrong_Network"
    FAILURE_CORE_INVALID_ADDRESS = "Failure_Core_Invalid_Address"
    FAILURE_CORE_INVALID_VERSION = "Failure_Core_Invalid_Version"
    FAILURE_CORE_INVALID_TRANSACTION_FEE = "Failure_Core_Invalid_Transaction_Fee"
    FAILURE_CORE_BLOCK_HARVESTER_INELIGIBLE = "Failure_Core_Block_Harvester_Ineligible"
    FAILURE_CORE_ZERO_ADDRESS = "Failure_Core_Zero_Address"
    FAILURE_CORE_ZERO_PUBLIC_KEY = "Failure_Core_Zero_Public_Key"
    FAILURE_CORE_NONZERO_INTERNAL_PADDING = "Failure_Core_Nonzero_Internal_Padding"
    FAILURE_CORE_ADDRESS_COLLISION = "Failure_Core_Address_Collision"
    FAILURE_CORE_IMPORTANCE_BLOCK_MISMATCH = "Failure_Core_Importance_Block_Mismatch"
    FAILURE_CORE_UNEXPECTED_BLOCK_TYPE = "Failure_Core_Unexpected_Block_Type"
    FAILURE_CORE_INVALID_LINK_ACTION = "Failure_Core_Invalid_Link_Action"
    FAILURE_CORE_LINK_ALREADY_EXISTS = "Failure_Core_Link_Already_Exists"
    FAILURE_CORE_INCONSISTENT_UNLINK_DATA = "Failure_Core_Inconsistent_Unlink_Data"
    FAILURE_CORE_INVALID_LINK_RANGE = "Failure_Core_Invalid_Link_Range"
    FAILURE_CORE_TOO_MANY_LINKS = "Failure_Core_Too_Many_Links"
    FAILURE_HASH_ALREADY_EXISTS = "Failure_Hash_Already_Exists"
    FAILURE_SIGNATURE_NOT_VERIFIABLE = "Failure_Signature_Not_Verifiable"
    FAILURE_ACCOUNTLINK_LINK_ALREADY_EXISTS = "Failure_AccountLink_Link_Already_Exists"
    FAILURE_ACCOUNTLINK_INCONSISTENT_UNLINK_DATA = "Failure_AccountLink_Inconsistent_Unlink_Data"
    FAILURE_ACCOUNTLINK_UNKNOWN_LINK = "Failure_AccountLink_Unknown_Link"
    FAILURE_ACCOUNTLINK_REMOTE_ACCOUNT_INELIGIBLE = "Failure_AccountLink_Remote_Account_Ineligible"
    FAILURE_ACCOUNTLINK_REMOTE_ACCOUNT_SIGNER_PROHIBITED = "Failure_AccountLink_Remote_Account_Signer_Prohibited"
    FAILURE_ACCOUNTLINK_REMOTE_ACCOUNT_PARTICIPANT_PROHIBITED = "Failure_AccountLink_Remote_Account_Participant_Prohibited"
    FAILURE_AGGREGATE_TOO_MANY_TRANSACTIONS = "Failure_Aggregate_Too_Many_Transactions"
    FAILURE_AGGREGATE_NO_TRANSACTIONS = "Failure_Aggregate_No_Transactions"
    FAILURE_AGGREGATE_TOO_MANY_COSIGNATURES = "Failure_Aggregate_Too_Many_Cosignatures"
    FAILURE_AGGREGATE_REDUNDANT_COSIGNATURES = "Failure_Aggregate_Redundant_Cosignatures"
    FAILURE_AGGREGATE_INELIGIBLE_COSIGNATORIES = "Failure_Aggregate_Ineligible_Cosignatories"
    FAILURE_AGGREGATE_MISSING_COSIGNATURES = "Failure_Aggregate_Missing_Cosignatures"
    FAILURE_AGGREGATE_TRANSACTIONS_HASH_MISMATCH = "Failure_Aggregate_Transactions_Hash_Mismatch"
    FAILURE_LOCKHASH_INVALID_MOSAIC_ID = "Failure_LockHash_Invalid_Mosaic_Id"
    FAILURE_LOCKHASH_INVALID_MOSAIC_AMOUNT = "Failure_LockHash_Invalid_Mosaic_Amount"
    FAILURE_LOCKHASH_HASH_ALREADY_EXISTS = "Failure_LockHash_Hash_Already_Exists"
    FAILURE_LOCKHASH_UNKNOWN_HASH = "Failure_LockHash_Unknown_Hash"
    FAILURE_LOCKHASH_INACTIVE_HASH = "Failure_LockHash_Inactive_Hash"
    FAILURE_LOCKHASH_INVALID_DURATION = "Failure_LockHash_Invalid_Duration"
    FAILURE_LOCKSECRET_INVALID_HASH_ALGORITHM = "Failure_LockSecret_Invalid_Hash_Algorithm"
    FAILURE_LOCKSECRET_HASH_ALREADY_EXISTS = "Failure_LockSecret_Hash_Already_Exists"
    FAILURE_LOCKSECRET_PROOF_SIZE_OUT_OF_BOUNDS = "Failure_LockSecret_Proof_Size_Out_Of_Bounds"
    FAILURE_LOCKSECRET_SECRET_MISMATCH = "Failure_LockSecret_Secret_Mismatch"
    FAILURE_LOCKSECRET_UNKNOWN_COMPOSITE_KEY = "Failure_LockSecret_Unknown_Composite_Key"
    FAILURE_LOCKSECRET_INACTIVE_SECRET = "Failure_LockSecret_Inactive_Secret"
    FAILURE_LOCKSECRET_HASH_ALGORITHM_MISMATCH = "Failure_LockSecret_Hash_Algorithm_Mismatch"
    FAILURE_LOCKSECRET_INVALID_DURATION = "Failure_LockSecret_Invalid_Duration"
    FAILURE_METADATA_VALUE_TOO_SMALL = "Failure_Metadata_Value_Too_Small"
    FAILURE_METADATA_VALUE_TOO_LARGE = "Failure_Metadata_Value_Too_Large"
    FAILURE_METADATA_VALUE_SIZE_DELTA_TOO_LARGE = "Failure_Metadata_Value_Size_Delta_Too_Large"
    FAILURE_METADATA_VALUE_SIZE_DELTA_MISMATCH = "Failure_Metadata_Value_Size_Delta_Mismatch"
    FAILURE_METADATA_VALUE_CHANGE_IRREVERSIBLE = "Failure_Metadata_Value_Change_Irreversible"
    FAILURE_MOSAIC_INVALID_DURATION = "Failure_Mosaic_Invalid_Duration"
    FAILURE_MOSAIC_INVALID_NAME = "Failure_Mosaic_Invalid_Name"
    FAILURE_MOSAIC_NAME_ID_MISMATCH = "Failure_Mosaic_Name_Id_Mismatch"
    FAILURE_MOSAIC_EXPIRED = "Failure_Mosaic_Expired"
    FAILURE_MOSAIC_OWNER_CONFLICT = "Failure_Mosaic_Owner_Conflict"
    FAILURE_MOSAIC_ID_MISMATCH = "Failure_Mosaic_Id_Mismatch"
    FAILURE_MOSAIC_PARENT_ID_CONFLICT = "Failure_Mosaic_Parent_Id_Conflict"
    FAILURE_MOSAIC_INVALID_PROPERTY = "Failure_Mosaic_Invalid_Property"
    FAILURE_MOSAIC_INVALID_FLAGS = "Failure_Mosaic_Invalid_Flags"
    FAILURE_MOSAIC_INVALID_DIVISIBILITY = "Failure_Mosaic_Invalid_Divisibility"
    FAILURE_MOSAIC_INVALID_SUPPLY_CHANGE_ACTION = "Failure_Mosaic_Invalid_Supply_Change_Action"
    FAILURE_MOSAIC_INVALID_SUPPLY_CHANGE_AMOUNT = "Failure_Mosaic_Invalid_Supply_Change_Amount"
    FAILURE_MOSAIC_INVALID_ID = "Failure_Mosaic_Invalid_Id"
    FAILURE_MOSAIC_MODIFICATION_DISALLOWED = "Failure_Mosaic_Modification_Disallowed"
    FAILURE_MOSAIC_MODIFICATION_NO_CHANGES = "Failure_Mosaic_Modification_No_Changes"
    FAILURE_MOSAIC_SUPPLY_IMMUTABLE = "Failure_Mosaic_Supply_Immutable"
    FAILURE_MOSAIC_SUPPLY_NEGATIVE = "Failure_Mosaic_Supply_Negative"
    FAILURE_MOSAIC_SUPPLY_EXCEEDED = "Failure_Mosaic_Supply_Exceeded"
    FAILURE_MOSAIC_NON_TRANSFERABLE = "Failure_Mosaic_Non_Transferable"
    FAILURE_MOSAIC_MAX_MOSAICS_EXCEEDED = "Failure_Mosaic_Max_Mosaics_Exceeded"
    FAILURE_MOSAIC_REQUIRED_PROPERTY_FLAG_UNSET = "Failure_Mosaic_Required_Property_Flag_Unset"
    FAILURE_MULTISIG_ACCOUNT_IN_BOTH_SETS = "Failure_Multisig_Account_In_Both_Sets"
    FAILURE_MULTISIG_MULTIPLE_DELETES = "Failure_Multisig_Multiple_Deletes"
    FAILURE_MULTISIG_REDUNDANT_MODIFICATION = "Failure_Multisig_Redundant_Modification"
    FAILURE_MULTISIG_UNKNOWN_MULTISIG_ACCOUNT = "Failure_Multisig_Unknown_Multisig_Account"
    FAILURE_MULTISIG_NOT_A_COSIGNATORY = "Failure_Multisig_Not_A_Cosignatory"
    FAILURE_MULTISIG_ALREADY_A_COSIGNATORY = "Failure_Multisig_Already_A_Cosignatory"
    FAILURE_MULTISIG_MIN_SETTING_OUT_OF_RANGE = "Failure_Multisig_Min_Setting_Out_Of_Range"
    FAILURE_MULTISIG_MIN_SETTING_LARGER_THAN_NUM_COSIGNATORIES = "Failure_Multisig_Min_Setting_Larger_Than_Num_Cosignatories"
    FAILURE_MULTISIG_INVALID_MODIFICATION_ACTION = "Failure_Multisig_Invalid_Modification_Action"
    FAILURE_MULTISIG_MAX_COSIGNED_ACCOUNTS = "Failure_Multisig_Max_Cosigned_Accounts"
    FAILURE_MULTISIG_MAX_COSIGNATORIES = "Failure_Multisig_Max_Cosignatories"
    FAILURE_MULTISIG_LOOP = "Failure_Multisig_Loop"
    FAILURE_MULTISIG_MAX_MULTISIG_DEPTH = "Failure_Multisig_Max_Multisig_Depth"
    FAILURE_MULTISIG_OPERATION_PROHIBITED_BY_ACCOUNT = "Failure_Multisig_Operation_Prohibited_By_Account"
    FAILURE_NAMESPACE_INVALID_DURATION = "Failure_Namespace_Invalid_Duration"
    FAILURE_NAMESPACE_INVALID_NAME = "Failure_Namespace_Invalid_Name"
    FAILURE_NAMESPACE_NAME_ID_MISMATCH = "Failure_Namespace_Name_Id_Mismatch"
    FAILURE_NAMESPACE_EXPIRED = "Failure_Namespace_Expired"
    FAILURE_NAMESPACE_OWNER_CONFLICT = "Failure_Namespace_Owner_Conflict"
    FAILURE_NAMESPACE_ID_MISMATCH = "Failure_Namespace_Id_Mismatch"
    FAILURE_NAMESPACE_INVALID_REGISTRATION_TYPE = "Failure_Namespace_Invalid_Registration_Type"
    FAILURE_NAMESPACE_ROOT_NAME_RESERVED = "Failure_Namespace_Root_Name_Reserved"
    FAILURE_NAMESPACE_TOO_DEEP = "Failure_Namespace_Too_Deep"
    FAILURE_NAMESPACE_UNKNOWN_PARENT = "Failure_Namespace_Unknown_Parent"
    FAILURE_NAMESPACE_ALREADY_EXISTS = "Failure_Namespace_Already_Exists"
    FAILURE_NAMESPACE_ALREADY_ACTIVE = "Failure_Namespace_Already_Active"
    FAILURE_NAMESPACE_ETERNAL_AFTER_NEMESIS_BLOCK = "Failure_Namespace_Eternal_After_Nemesis_Block"
    FAILURE_NAMESPACE_MAX_CHILDREN_EXCEEDED = "Failure_Namespace_Max_Children_Exceeded"
    FAILURE_NAMESPACE_ALIAS_INVALID_ACTION = "Failure_Namespace_Alias_Invalid_Action"
    FAILURE_NAMESPACE_UNKNOWN = "Failure_Namespace_Unknown"
    FAILURE_NAMESPACE_ALIAS_ALREADY_EXISTS = "Failure_Namespace_Alias_Already_Exists"
    FAILURE_NAMESPACE_UNKNOWN_ALIAS = "Failure_Namespace_Unknown_Alias"
    FAILURE_NAMESPACE_ALIAS_INCONSISTENT_UNLINK_TYPE = "Failure_Namespace_Alias_Inconsistent_Unlink_Type"
    FAILURE_NAMESPACE_ALIAS_INCONSISTENT_UNLINK_DATA = "Failure_Namespace_Alias_Inconsistent_Unlink_Data"
    FAILURE_NAMESPACE_ALIAS_INVALID_ADDRESS = "Failure_Namespace_Alias_Invalid_Address"
    FAILURE_RESTRICTIONACCOUNT_INVALID_RESTRICTION_FLAGS = "Failure_RestrictionAccount_Invalid_Restriction_Flags"
    FAILURE_RESTRICTIONACCOUNT_INVALID_MODIFICATION_ACTION = "Failure_RestrictionAccount_Invalid_Modification_Action"
    FAILURE_RESTRICTIONACCOUNT_INVALID_MODIFICATION_ADDRESS = "Failure_RestrictionAccount_Invalid_Modification_Address"
    FAILURE_RESTRICTIONACCOUNT_MODIFICATION_OPERATION_TYPE_INCOMPATIBLE = "Failure_RestrictionAccount_Modification_Operation_Type_Incompatible"
    FAILURE_RESTRICTIONACCOUNT_REDUNDANT_MODIFICATION = "Failure_RestrictionAccount_Redundant_Modification"
    FAILURE_RESTRICTIONACCOUNT_INVALID_MODIFICATION = "Failure_RestrictionAccount_Invalid_Modification"
    FAILURE_RESTRICTIONACCOUNT_MODIFICATION_COUNT_EXCEEDED = "Failure_RestrictionAccount_Modification_Count_Exceeded"
    FAILURE_RESTRICTIONACCOUNT_NO_MODIFICATIONS = "Failure_RestrictionAccount_No_Modifications"
    FAILURE_RESTRICTIONACCOUNT_VALUES_COUNT_EXCEEDED = "Failure_RestrictionAccount_Values_Count_Exceeded"
    FAILURE_RESTRICTIONACCOUNT_INVALID_VALUE = "Failure_RestrictionAccount_Invalid_Value"
    FAILURE_RESTRICTIONACCOUNT_ADDRESS_INTERACTION_PROHIBITED = "Failure_RestrictionAccount_Address_Interaction_Prohibited"
    FAILURE_RESTRICTIONACCOUNT_MOSAIC_TRANSFER_PROHIBITED = "Failure_RestrictionAccount_Mosaic_Transfer_Prohibited"
    FAILURE_RESTRICTIONACCOUNT_OPERATION_TYPE_PROHIBITED = "Failure_RestrictionAccount_Operation_Type_Prohibited"
    FAILURE_RESTRICTIONMOSAIC_INVALID_RESTRICTION_TYPE = "Failure_RestrictionMosaic_Invalid_Restriction_Type"
    FAILURE_RESTRICTIONMOSAIC_PREVIOUS_VALUE_MISMATCH = "Failure_RestrictionMosaic_Previous_Value_Mismatch"
    FAILURE_RESTRICTIONMOSAIC_PREVIOUS_VALUE_MUST_BE_ZERO = "Failure_RestrictionMosaic_Previous_Value_Must_Be_Zero"
    FAILURE_RESTRICTIONMOSAIC_MAX_RESTRICTIONS_EXCEEDED = "Failure_RestrictionMosaic_Max_Restrictions_Exceeded"
    FAILURE_RESTRICTIONMOSAIC_CANNOT_DELETE_NONEXISTENT_RESTRICTION = "Failure_RestrictionMosaic_Cannot_Delete_Nonexistent_Restriction"
    FAILURE_RESTRICTIONMOSAIC_UNKNOWN_GLOBAL_RESTRICTION = "Failure_RestrictionMosaic_Unknown_Global_Restriction"
    FAILURE_RESTRICTIONMOSAIC_INVALID_GLOBAL_RESTRICTION = "Failure_RestrictionMosaic_Invalid_Global_Restriction"
    FAILURE_RESTRICTIONMOSAIC_ACCOUNT_UNAUTHORIZED = "Failure_RestrictionMosaic_Account_Unauthorized"
    FAILURE_TRANSFER_MESSAGE_TOO_LARGE = "Failure_Transfer_Message_Too_Large"
    FAILURE_TRANSFER_OUT_OF_ORDER_MOSAICS = "Failure_Transfer_Out_Of_Order_Mosaics"
    FAILURE_CHAIN_UNLINKED = "Failure_Chain_Unlinked"
    FAILURE_CHAIN_BLOCK_NOT_HIT = "Failure_Chain_Block_Not_Hit"
    FAILURE_CHAIN_BLOCK_INCONSISTENT_STATE_HASH = "Failure_Chain_Block_Inconsistent_State_Hash"
    FAILURE_CHAIN_BLOCK_INCONSISTENT_RECEIPTS_HASH = "Failure_Chain_Block_Inconsistent_Receipts_Hash"
    FAILURE_CHAIN_BLOCK_INVALID_VRF_PROOF = "Failure_Chain_Block_Invalid_Vrf_Proof"
    FAILURE_CHAIN_BLOCK_UNKNOWN_SIGNER = "Failure_Chain_Block_Unknown_Signer"
    FAILURE_CHAIN_UNCONFIRMED_CACHE_TOO_FULL = "Failure_Chain_Unconfirmed_Cache_Too_Full"
    FAILURE_CONSUMER_EMPTY_INPUT = "Failure_Consumer_Empty_Input"
    FAILURE_CONSUMER_BLOCK_TRANSACTIONS_HASH_MISMATCH = "Failure_Consumer_Block_Transactions_Hash_Mismatch"
    NEUTRAL_CONSUMER_HASH_IN_RECENCY_CACHE = "Neutral_Consumer_Hash_In_Recency_Cache"
    FAILURE_CONSUMER_REMOTE_CHAIN_TOO_MANY_BLOCKS = "Failure_Consumer_Remote_Chain_Too_Many_Blocks"
    FAILURE_CONSUMER_REMOTE_CHAIN_IMPROPER_LINK = "Failure_Consumer_Remote_Chain_Improper_Link"
    FAILURE_CONSUMER_REMOTE_CHAIN_DUPLICATE_TRANSACTIONS = "Failure_Consumer_Remote_Chain_Duplicate_Transactions"
    FAILURE_CONSUMER_REMOTE_CHAIN_UNLINKED = "Failure_Consumer_Remote_Chain_Unlinked"
    FAILURE_CONSUMER_REMOTE_CHAIN_DIFFICULTIES_MISMATCH = "Failure_Consumer_Remote_Chain_Difficulties_Mismatch"
    FAILURE_CONSUMER_REMOTE_CHAIN_SCORE_NOT_BETTER = "Failure_Consumer_Remote_Chain_Score_Not_Better"
    FAILURE_CONSUMER_REMOTE_CHAIN_TOO_FAR_BEHIND = "Failure_Consumer_Remote_Chain_Too_Far_Behind"
    FAILURE_CONSUMER_REMOTE_CHAIN_TOO_FAR_IN_FUTURE = "Failure_Consumer_Remote_Chain_Too_Far_In_Future"
    FAILURE_CONSUMER_BATCH_SIGNATURE_NOT_VERIFIABLE = "Failure_Consumer_Batch_Signature_Not_Verifiable"
    FAILURE_CONSUMER_REMOTE_CHAIN_IMPROPER_IMPORTANCE_LINK = "Failure_Consumer_Remote_Chain_Improper_Importance_Link"
    FAILURE_EXTENSION_PARTIAL_TRANSACTION_CACHE_PRUNE = "Failure_Extension_Partial_Transaction_Cache_Prune"
    FAILURE_EXTENSION_PARTIAL_TRANSACTION_DEPENDENCY_REMOVED = "Failure_Extension_Partial_Transaction_Dependency_Removed"
    FAILURE_EXTENSION_READ_RATE_LIMIT_EXCEEDED = "Failure_Extension_Read_Rate_Limit_Exceeded"

    allowable_values = [SUCCESS, NEUTRAL, FAILURE, FAILURE_CORE_PAST_DEADLINE, FAILURE_CORE_FUTURE_DEADLINE, FAILURE_CORE_INSUFFICIENT_BALANCE, FAILURE_CORE_TOO_MANY_TRANSACTIONS, FAILURE_CORE_NEMESIS_ACCOUNT_SIGNED_AFTER_NEMESIS_BLOCK, FAILURE_CORE_WRONG_NETWORK, FAILURE_CORE_INVALID_ADDRESS, FAILURE_CORE_INVALID_VERSION, FAILURE_CORE_INVALID_TRANSACTION_FEE, FAILURE_CORE_BLOCK_HARVESTER_INELIGIBLE, FAILURE_CORE_ZERO_ADDRESS, FAILURE_CORE_ZERO_PUBLIC_KEY, FAILURE_CORE_NONZERO_INTERNAL_PADDING, FAILURE_CORE_ADDRESS_COLLISION, FAILURE_CORE_IMPORTANCE_BLOCK_MISMATCH, FAILURE_CORE_UNEXPECTED_BLOCK_TYPE, FAILURE_CORE_INVALID_LINK_ACTION, FAILURE_CORE_LINK_ALREADY_EXISTS, FAILURE_CORE_INCONSISTENT_UNLINK_DATA, FAILURE_CORE_INVALID_LINK_RANGE, FAILURE_CORE_TOO_MANY_LINKS, FAILURE_HASH_ALREADY_EXISTS, FAILURE_SIGNATURE_NOT_VERIFIABLE, FAILURE_ACCOUNTLINK_LINK_ALREADY_EXISTS, FAILURE_ACCOUNTLINK_INCONSISTENT_UNLINK_DATA, FAILURE_ACCOUNTLINK_UNKNOWN_LINK, FAILURE_ACCOUNTLINK_REMOTE_ACCOUNT_INELIGIBLE, FAILURE_ACCOUNTLINK_REMOTE_ACCOUNT_SIGNER_PROHIBITED, FAILURE_ACCOUNTLINK_REMOTE_ACCOUNT_PARTICIPANT_PROHIBITED, FAILURE_AGGREGATE_TOO_MANY_TRANSACTIONS, FAILURE_AGGREGATE_NO_TRANSACTIONS, FAILURE_AGGREGATE_TOO_MANY_COSIGNATURES, FAILURE_AGGREGATE_REDUNDANT_COSIGNATURES, FAILURE_AGGREGATE_INELIGIBLE_COSIGNATORIES, FAILURE_AGGREGATE_MISSING_COSIGNATURES, FAILURE_AGGREGATE_TRANSACTIONS_HASH_MISMATCH, FAILURE_LOCKHASH_INVALID_MOSAIC_ID, FAILURE_LOCKHASH_INVALID_MOSAIC_AMOUNT, FAILURE_LOCKHASH_HASH_ALREADY_EXISTS, FAILURE_LOCKHASH_UNKNOWN_HASH, FAILURE_LOCKHASH_INACTIVE_HASH, FAILURE_LOCKHASH_INVALID_DURATION, FAILURE_LOCKSECRET_INVALID_HASH_ALGORITHM, FAILURE_LOCKSECRET_HASH_ALREADY_EXISTS, FAILURE_LOCKSECRET_PROOF_SIZE_OUT_OF_BOUNDS, FAILURE_LOCKSECRET_SECRET_MISMATCH, FAILURE_LOCKSECRET_UNKNOWN_COMPOSITE_KEY, FAILURE_LOCKSECRET_INACTIVE_SECRET, FAILURE_LOCKSECRET_HASH_ALGORITHM_MISMATCH, FAILURE_LOCKSECRET_INVALID_DURATION, FAILURE_METADATA_VALUE_TOO_SMALL, FAILURE_METADATA_VALUE_TOO_LARGE, FAILURE_METADATA_VALUE_SIZE_DELTA_TOO_LARGE, FAILURE_METADATA_VALUE_SIZE_DELTA_MISMATCH, FAILURE_METADATA_VALUE_CHANGE_IRREVERSIBLE, FAILURE_MOSAIC_INVALID_DURATION, FAILURE_MOSAIC_INVALID_NAME, FAILURE_MOSAIC_NAME_ID_MISMATCH, FAILURE_MOSAIC_EXPIRED, FAILURE_MOSAIC_OWNER_CONFLICT, FAILURE_MOSAIC_ID_MISMATCH, FAILURE_MOSAIC_PARENT_ID_CONFLICT, FAILURE_MOSAIC_INVALID_PROPERTY, FAILURE_MOSAIC_INVALID_FLAGS, FAILURE_MOSAIC_INVALID_DIVISIBILITY, FAILURE_MOSAIC_INVALID_SUPPLY_CHANGE_ACTION, FAILURE_MOSAIC_INVALID_SUPPLY_CHANGE_AMOUNT, FAILURE_MOSAIC_INVALID_ID, FAILURE_MOSAIC_MODIFICATION_DISALLOWED, FAILURE_MOSAIC_MODIFICATION_NO_CHANGES, FAILURE_MOSAIC_SUPPLY_IMMUTABLE, FAILURE_MOSAIC_SUPPLY_NEGATIVE, FAILURE_MOSAIC_SUPPLY_EXCEEDED, FAILURE_MOSAIC_NON_TRANSFERABLE, FAILURE_MOSAIC_MAX_MOSAICS_EXCEEDED, FAILURE_MOSAIC_REQUIRED_PROPERTY_FLAG_UNSET, FAILURE_MULTISIG_ACCOUNT_IN_BOTH_SETS, FAILURE_MULTISIG_MULTIPLE_DELETES, FAILURE_MULTISIG_REDUNDANT_MODIFICATION, FAILURE_MULTISIG_UNKNOWN_MULTISIG_ACCOUNT, FAILURE_MULTISIG_NOT_A_COSIGNATORY, FAILURE_MULTISIG_ALREADY_A_COSIGNATORY, FAILURE_MULTISIG_MIN_SETTING_OUT_OF_RANGE, FAILURE_MULTISIG_MIN_SETTING_LARGER_THAN_NUM_COSIGNATORIES, FAILURE_MULTISIG_INVALID_MODIFICATION_ACTION, FAILURE_MULTISIG_MAX_COSIGNED_ACCOUNTS, FAILURE_MULTISIG_MAX_COSIGNATORIES, FAILURE_MULTISIG_LOOP, FAILURE_MULTISIG_MAX_MULTISIG_DEPTH, FAILURE_MULTISIG_OPERATION_PROHIBITED_BY_ACCOUNT, FAILURE_NAMESPACE_INVALID_DURATION, FAILURE_NAMESPACE_INVALID_NAME, FAILURE_NAMESPACE_NAME_ID_MISMATCH, FAILURE_NAMESPACE_EXPIRED, FAILURE_NAMESPACE_OWNER_CONFLICT, FAILURE_NAMESPACE_ID_MISMATCH, FAILURE_NAMESPACE_INVALID_REGISTRATION_TYPE, FAILURE_NAMESPACE_ROOT_NAME_RESERVED, FAILURE_NAMESPACE_TOO_DEEP, FAILURE_NAMESPACE_UNKNOWN_PARENT, FAILURE_NAMESPACE_ALREADY_EXISTS, FAILURE_NAMESPACE_ALREADY_ACTIVE, FAILURE_NAMESPACE_ETERNAL_AFTER_NEMESIS_BLOCK, FAILURE_NAMESPACE_MAX_CHILDREN_EXCEEDED, FAILURE_NAMESPACE_ALIAS_INVALID_ACTION, FAILURE_NAMESPACE_UNKNOWN, FAILURE_NAMESPACE_ALIAS_ALREADY_EXISTS, FAILURE_NAMESPACE_UNKNOWN_ALIAS, FAILURE_NAMESPACE_ALIAS_INCONSISTENT_UNLINK_TYPE, FAILURE_NAMESPACE_ALIAS_INCONSISTENT_UNLINK_DATA, FAILURE_NAMESPACE_ALIAS_INVALID_ADDRESS, FAILURE_RESTRICTIONACCOUNT_INVALID_RESTRICTION_FLAGS, FAILURE_RESTRICTIONACCOUNT_INVALID_MODIFICATION_ACTION, FAILURE_RESTRICTIONACCOUNT_INVALID_MODIFICATION_ADDRESS, FAILURE_RESTRICTIONACCOUNT_MODIFICATION_OPERATION_TYPE_INCOMPATIBLE, FAILURE_RESTRICTIONACCOUNT_REDUNDANT_MODIFICATION, FAILURE_RESTRICTIONACCOUNT_INVALID_MODIFICATION, FAILURE_RESTRICTIONACCOUNT_MODIFICATION_COUNT_EXCEEDED, FAILURE_RESTRICTIONACCOUNT_NO_MODIFICATIONS, FAILURE_RESTRICTIONACCOUNT_VALUES_COUNT_EXCEEDED, FAILURE_RESTRICTIONACCOUNT_INVALID_VALUE, FAILURE_RESTRICTIONACCOUNT_ADDRESS_INTERACTION_PROHIBITED, FAILURE_RESTRICTIONACCOUNT_MOSAIC_TRANSFER_PROHIBITED, FAILURE_RESTRICTIONACCOUNT_OPERATION_TYPE_PROHIBITED, FAILURE_RESTRICTIONMOSAIC_INVALID_RESTRICTION_TYPE, FAILURE_RESTRICTIONMOSAIC_PREVIOUS_VALUE_MISMATCH, FAILURE_RESTRICTIONMOSAIC_PREVIOUS_VALUE_MUST_BE_ZERO, FAILURE_RESTRICTIONMOSAIC_MAX_RESTRICTIONS_EXCEEDED, FAILURE_RESTRICTIONMOSAIC_CANNOT_DELETE_NONEXISTENT_RESTRICTION, FAILURE_RESTRICTIONMOSAIC_UNKNOWN_GLOBAL_RESTRICTION, FAILURE_RESTRICTIONMOSAIC_INVALID_GLOBAL_RESTRICTION, FAILURE_RESTRICTIONMOSAIC_ACCOUNT_UNAUTHORIZED, FAILURE_TRANSFER_MESSAGE_TOO_LARGE, FAILURE_TRANSFER_OUT_OF_ORDER_MOSAICS, FAILURE_CHAIN_UNLINKED, FAILURE_CHAIN_BLOCK_NOT_HIT, FAILURE_CHAIN_BLOCK_INCONSISTENT_STATE_HASH, FAILURE_CHAIN_BLOCK_INCONSISTENT_RECEIPTS_HASH, FAILURE_CHAIN_BLOCK_INVALID_VRF_PROOF, FAILURE_CHAIN_BLOCK_UNKNOWN_SIGNER, FAILURE_CHAIN_UNCONFIRMED_CACHE_TOO_FULL, FAILURE_CONSUMER_EMPTY_INPUT, FAILURE_CONSUMER_BLOCK_TRANSACTIONS_HASH_MISMATCH, NEUTRAL_CONSUMER_HASH_IN_RECENCY_CACHE, FAILURE_CONSUMER_REMOTE_CHAIN_TOO_MANY_BLOCKS, FAILURE_CONSUMER_REMOTE_CHAIN_IMPROPER_LINK, FAILURE_CONSUMER_REMOTE_CHAIN_DUPLICATE_TRANSACTIONS, FAILURE_CONSUMER_REMOTE_CHAIN_UNLINKED, FAILURE_CONSUMER_REMOTE_CHAIN_DIFFICULTIES_MISMATCH, FAILURE_CONSUMER_REMOTE_CHAIN_SCORE_NOT_BETTER, FAILURE_CONSUMER_REMOTE_CHAIN_TOO_FAR_BEHIND, FAILURE_CONSUMER_REMOTE_CHAIN_TOO_FAR_IN_FUTURE, FAILURE_CONSUMER_BATCH_SIGNATURE_NOT_VERIFIABLE, FAILURE_CONSUMER_REMOTE_CHAIN_IMPROPER_IMPORTANCE_LINK, FAILURE_EXTENSION_PARTIAL_TRANSACTION_CACHE_PRUNE, FAILURE_EXTENSION_PARTIAL_TRANSACTION_DEPENDENCY_REMOVED, FAILURE_EXTENSION_READ_RATE_LIMIT_EXCEEDED]  # noqa: E501

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
    }

    attribute_map = {
    }

    def __init__(self, local_vars_configuration=None):  # noqa: E501
        """TransactionStatusEnum - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TransactionStatusEnum):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TransactionStatusEnum):
            return True

        return self.to_dict() != other.to_dict()
